Index: third_party/WebKit/public/web/WebDocument.h |
diff --git a/third_party/WebKit/public/web/WebDocument.h b/third_party/WebKit/public/web/WebDocument.h |
index 2960c6d905b1756e65e2bf3a5e64f2c84d4c2c79..3db06b6a730f073140b01c3e14a6ffb799ab2f59 100644 |
--- a/third_party/WebKit/public/web/WebDocument.h |
+++ b/third_party/WebKit/public/web/WebDocument.h |
@@ -74,8 +74,8 @@ public: |
void assign(const WebDocument& e) { WebNode::assign(e); } |
BLINK_EXPORT WebURL url() const; |
- // Note: Security checks should use the securityOrigin(), not url(). |
- BLINK_EXPORT WebSecurityOrigin securityOrigin() const; |
+ // Note: Security checks should use the getSecurityOrigin(), not url(). |
+ BLINK_EXPORT WebSecurityOrigin getSecurityOrigin() const; |
BLINK_EXPORT bool isSecureContext(WebString& errorMessage) const; |
BLINK_EXPORT WebString encoding() const; |